<?php
namespace CourierManager\Shipping\Model\Carrier;

use CourierManager\Shipping\Version;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\Config\Value;
use Magento\Framework\App\ObjectManager;
use Magento\Framework\Message\Error;
use Magento\Framework\Phrase;
use Magento\Framework\Validator\Exception;
use Magento\Store\Model\StoreManagerInterface;

class ApiAuthValidate extends Value
{
    /** @var ScopeConfigInterface */
    protected $scopeConfig;

    /** @var StoreManagerInterface */
    protected $storeManager;

    /**
     * @return ApiAuthValidate|void
     * @throws Exception
     */
    public function validateBeforeSave()
    {
        $objManager = ObjectManager::getInstance();
        $magentoVersion = $objManager->get('Magento\Framework\App\ProductMetadataInterface');

        $pluginVersion = [
            "platform" => "Magento",
            "platformVersion" => $magentoVersion->getVersion(),
            "pluginVersion" => Version::PLUGIN_VERSION,
        ];
        $apiClient = new CourierManagerApi($this->getData('fieldset_data/api_url'), $this->getValue(), $pluginVersion);
        $apiClient->getServicesList();
        if($apiClient->getError()) {
            $exception = new Exception(new Phrase($apiClient->getError()));
            $exception->addMessage(new Error($apiClient->getError()));
            throw $exception;
        }

        parent::validateBeforeSave();
    }


}
