<?php

namespace CourierManager\Shipping\Model\Carrier\Types;

use CourierManager\Shipping\Model\Carrier\CourierManagerApi;
use CourierManager\Shipping\Version;
use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\App\ProductMetadataInterface;
use Magento\Framework\Data\OptionSourceInterface;
use Magento\Framework\Exception\NoSuchEntityException;
use Magento\Store\Model\ScopeInterface;
use Magento\Store\Model\StoreManagerInterface;

class DeliveryTypeCode implements OptionSourceInterface
{
    /** @var ScopeConfigInterface */
    protected $scopeConfig;

    /** @var StoreManagerInterface */
    protected $storeManager;

    /** @var ProductMetadataInterface */
    private $productMetadata;

    /**
     * @param ScopeConfigInterface $scopeConfig
     * @param StoreManagerInterface $storeManager
     * @param ProductMetadataInterface $productMetadata
     */
    public function __construct(
        ScopeConfigInterface $scopeConfig,
        StoreManagerInterface $storeManager,
        ProductMetadataInterface $productMetadata
    )
    {
        $this->scopeConfig = $scopeConfig;
        $this->storeManager = $storeManager;
        $this->productMetadata = $productMetadata;
    }

    /**
     * @return array
     * @throws NoSuchEntityException
     */
    public function toOptionArray(): array
    {
        $deliveryTypeCodes = [];
        if ($this->getConfigData('api_url') && $this->getConfigData('api_key')) {
            $pluginVersion = [
                "platform" => "Magento",
                "platformVersion" => $this->productMetadata->getVersion(),
                "pluginVersion" => Version::PLUGIN_VERSION,
            ];
            $apiClient = new CourierManagerApi(
                $this->getConfigData('api_url'),
                $this->getConfigData('api_key'),
                $pluginVersion
            );

            $deliveryServices = $apiClient->getServicesList();
            if(!$apiClient->getError()) {
                foreach ($deliveryServices as $service) {
                    $deliveryTypeCodes[] = ['value' => $service->value, 'label' => $service->name];
                }
            }
        }

        return $deliveryTypeCodes;
    }

    /**
     * @param $field
     * @return mixed
     * @throws NoSuchEntityException
     */
    public function getConfigData($field)
    {
        return $this->scopeConfig->getValue(
            'carriers/couriermanager/' . $field,
            ScopeInterface::SCOPE_STORE,
            $this->storeManager->getStore()->getId()
        );
    }
}
